@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2015 by Elvis Angelaccio <elvis.angelaccio@kdemail.net>
+    Copyright (C) 2015 by Elvis Angelaccio <elvis.angelaccio@kde.org>
 
     This file is part of Kronometer.
 
@@ -24,6 +24,7 @@
 #include <KMessageBox>
 #include <KMessageWidget>
 
+#include <QDesktopWidget>
 #include <QDialogButtonBox>
 #include <QHeaderView>
 #include <QKeyEvent>
@@ -57,6 +58,10 @@ SessionDialog::SessionDialog(QWidget *parent, const QString& title) : QDialog(pa
 
     slotEmptyModel();
     slotSelectionChanged();
+
+    auto desktopWidget = QApplication::desktop();
+    // Set a good default size, tested on 1920x1200 and 1366x768 screens.
+    resize(desktopWidget->screenGeometry().size() / 2.5);
 }
 
 Session SessionDialog::selectedSession() const
